@@ -28,11 +28,3 @@ pub fn oce() {
     write!(output_file, "$ {}\n{}", input.join(" "), result.trim())
         .expect("Couldn't output anything.");
 }
-
-#[cfg(test)]
-mod tests {
-    #[test]
-    fn it_works() {
-        assert_eq!(2 + 2, 4);
-    }
-}
